#!/usr/bin/env python3

"""Default stylesheet data and processing for dragonglass."""

from pathlib import Path
from jinja2 import Environment

"""Name of the default stylesheet."""
STYLESHEET_NAME = "dragonglass.css"

"""Template data for the default stylesheet."""
STYLESHEET_DATA = """/* Dragonglass default CSS file - ensure all generated HTML pages reference this */
a {
    color: #8a5cf5;     
}
.invalid-reference {
    color: #ad8df8;
    text-decoration: underline;
    text-decoration-color: #e6ddfd;
}
ins {
    background-color: #ffec99;
    text-decoration: none;
}
"""


def write_default_stylesheet(tenv: Environment, dest_dir: Path) -> None:
    """
    Writes the default stylesheet data to the destination directory.

    Args:
        tenv (Environment): Template engine used to render the default stylesheet data.
        dest_dir (Path): The destination directory to write the stylesheet to.
    """
    to_file = dest_dir / STYLESHEET_NAME
    tmpl = tenv.from_string(STYLESHEET_DATA)
    data = tmpl.render({})
    with to_file.open("wt") as f:
        f.write(data)
